@@ -1,5 +1,5 @@
 /*
- * $Id: 90s4414.h,v 1.2 2008/01/05 22:27:04 joerg_wunsch Exp $
+ * $Id: 90s4414.h,v 1.3 2008/03/19 22:39:03 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -145,9 +145,27 @@ static DevSuppDefn defn_at90s4414 = {
             .rd_mask = 0xff,
             .wr_mask = 0xff,
         },
-        { .addr = 0x3c, .name = "EECR", },
-        { .addr = 0x3d, .name = "EEDR", },
-        { .addr = 0x3e, .name = "EEARL", },
+        {
+	    .addr = 0x3c,
+	    .name = "EECR",
+	    .vdev_create = eeprom_create,
+	    .rd_mask = 0x07,
+	    .wr_mask = 0x07,
+	},
+        {
+	    .addr = 0x3d,
+	    .name = "EEDR",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
+        {
+	    .addr = 0x3e,
+	    .name = "EEARL",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
         { .addr = 0x41, .name = "WDTCR", },
         { .addr = 0x44, .name = "ICR1L", },
         { .addr = 0x45, .name = "ICR1H", },
