@@ -1,5 +1,5 @@
 /*
- * $Id: mega103.h,v 1.2 2008/01/05 22:27:05 joerg_wunsch Exp $
+ * $Id: mega103.h,v 1.3 2008/03/19 22:39:03 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -181,6 +181,42 @@ static DevSuppDefn defn_atmega103 = {
             .rd_mask = 0xff,
             .wr_mask = 0xff,
         },
+        {
+            .addr = 0x3b,
+            .name = "PORTA",
+            .ref_addr = 0x39,
+            .reset_value = 0x00,
+            .rd_mask = 0xff,
+            .wr_mask = 0xff,
+        },
+        {
+	    .addr = 0x3c,
+	    .name = "EECR",
+	    .vdev_create = eeprom_create,
+	    .rd_mask = 0x0f,
+	    .wr_mask = 0x0f,
+	},
+        {
+	    .addr = 0x3d,
+	    .name = "EEDR",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
+        {
+	    .addr = 0x3e,
+	    .name = "EEARL",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
+        {
+	    .addr = 0x3f,
+	    .name = "EEARH",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0x0f,
+	    .wr_mask = 0x0f,
+	},
         { .addr = 0x41, .name = "WDTCR", },
         { .addr = 0x43, .name = "OCR2", },
         { .addr = 0x44, .name = "TCNT2", },
