@@ -1,5 +1,5 @@
 /*
- * $Id: devsupp.c,v 1.30 2008/01/06 21:34:16 joerg_wunsch Exp $
+ * $Id: devsupp.c,v 1.31 2008/03/19 22:39:01 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -202,6 +202,12 @@ dev_supp_get_sram_sz (DevSuppDefn *dev)
     return dev->size.sram;
 }
 
+int
+dev_supp_get_eeprom_sz (DevSuppDefn *dev)
+{
+    return dev->size.eeprom;
+}
+
 int
 dev_supp_get_xram_sz (DevSuppDefn *dev)
 {
