@@ -1,5 +1,5 @@
 /*
- * $Id: intvects.h,v 1.8 2008/03/16 21:14:08 joerg_wunsch Exp $
+ * $Id: intvects.h,v 1.9 2011/06/30 05:51:10 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -26,6 +26,8 @@
 #ifndef SIM_INTVECTS_H
 #define SIM_INTVECTS_H
 
+#include <stddef.h>
+
 enum _sleep_modes
 {
     SLEEP_MODE_IDLE,
@@ -83,7 +85,7 @@ struct _IntVect
    an index enumeration. */
 
 #define irq_vect_table_index(vect) \
-    ( ((unsigned int) (&( ((IntVectTable *)(0)) -> vect))) / sizeof(IntVect) )
+    ( offsetof(IntVectTable, vect) / sizeof(IntVect) )
 
 /* No device will have all of these vectors, but must define a structure which
    has a slot for each interrupt. If the device doesn't support the
